package com.abi.qms.platform.controller.console;

import com.abi.qms.platform.dto.req.*;
import com.abi.qms.platform.dto.res.ExcelImportRes;
import com.abi.qms.platform.dto.res.GetDeptDetailRes;
import com.abi.qms.platform.dto.res.ListDeptRes;
import com.abi.qms.platform.service.DepartmentService;
import com.abi.task.common.api.base.BaseResponse;
import com.abi.task.common.excel.ExcelInputFactory;
import com.abi.task.common.excel.preperties.DepartmentProperty;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * <p>
 * 部门管理
 * </p>
 *
 * @author Andy.Tan
 */
@Slf4j
@RestController
@RequestMapping("dept")
@Api(tags = "部门管理")
public class DepartmentController {

    @Autowired
    private DepartmentService departmentService;

    @ApiOperation("部门新增修改")
    @PostMapping("saveDept")
    public BaseResponse saveDept(@Validated @RequestBody SaveDeptReq saveDeptReq) throws Exception{
        //部门新增修改
        departmentService.saveDept(saveDeptReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("部门查询分页")
    @GetMapping("listDept")
    public BaseResponse<ListDeptRes> listDept(@Validated ListDeptReq listDeptReq) throws Exception{
        //部门查询分页
        ListDeptRes  result = departmentService.listDept(listDeptReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("部门查询详情")
    @GetMapping("getDeptDetail")
    public BaseResponse<GetDeptDetailRes> getDeptDetail(@Validated GetDeptDetailReq getDeptDetailReq) throws Exception{
        //部门查询详情
        GetDeptDetailRes  result = departmentService.getDeptDetail(getDeptDetailReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("部门启用")
    @PostMapping("enableDept")
    public BaseResponse enableDept(@Validated @RequestBody EnableDeptReq enableDeptReq) throws Exception{
        //部门启用
        departmentService.enableDept(enableDeptReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("部门禁用")
    @PostMapping("disableDept")
    public BaseResponse disableDept(@Validated @RequestBody DisableDeptReq disableDeptReq) throws Exception{
        //部门禁用
        departmentService.disableDept(disableDeptReq);
        //包装出参
        return BaseResponse.create();
    }

    @ResponseBody
    @ApiOperation(value = "导出模板")
    @GetMapping("downloadExcelModel")
    public void downloadExcelModel(HttpServletResponse response) throws Exception {
        ExcelInputFactory.downloadExcelModel("部门模板", response, DepartmentProperty.class);
    }

    @ApiOperation("excel批量导入")
    @PostMapping("deptExcelImport")
    public BaseResponse<ExcelImportRes> deptExcelImport(@RequestParam("file") MultipartFile file) throws Exception{
        List<DepartmentProperty> departmentPropertyList = ExcelInputFactory.getExcelPojoList(file, DepartmentProperty.class);
        //excel批量导入
        ExcelImportRes result = departmentService.deptExcelImport(departmentPropertyList);
        //包装出参
        return BaseResponse.create(result);
    }



}








