package com.abi.qms.platform.controller.console;

import com.abi.qms.platform.dto.req.*;
import com.abi.qms.platform.dto.res.ExcelImportRes;
import com.abi.qms.platform.dto.res.GetFactoryDetailRes;
import com.abi.qms.platform.dto.res.ListFactoryRes;
import com.abi.qms.platform.service.FactoryService;
import com.abi.task.common.api.base.BaseResponse;
import com.abi.task.common.excel.ExcelInputFactory;
import com.abi.task.common.excel.preperties.DepartmentProperty;
import com.abi.task.common.excel.preperties.FactoryProperty;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * <p>
 * 供应商管理
 * </p>
 *
 * @author Andy.Tan
 */
@Slf4j
@RestController
@RequestMapping("factory")
@Api(tags = "供应商管理")
public class FactoryController {

    @Autowired
    private FactoryService factoryService;

    @ApiOperation("供应商新增修改")
    @PostMapping("saveFactory")
    public BaseResponse saveFactory(@Validated @RequestBody SaveFactoryReq saveFactoryReq) throws Exception{
        //供应商新增修改
        factoryService.saveFactory(saveFactoryReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("供应商查询分页")
    @GetMapping("listFactory")
    public BaseResponse<ListFactoryRes> listFactory(@Validated ListFactoryReq listFactoryReq) throws Exception{
        //供应商查询分页
        ListFactoryRes  result = factoryService.listFactory(listFactoryReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("供应商查询详情")
    @GetMapping("getFactoryDetail")
    public BaseResponse<GetFactoryDetailRes> getFactoryDetail(@Validated GetFactoryDetailReq getFactoryDetailReq) throws Exception{
        //供应商查询详情
        GetFactoryDetailRes  result = factoryService.getFactoryDetail(getFactoryDetailReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("供应商启用")
    @PostMapping("enableFactory")
    public BaseResponse enableFactory(@Validated @RequestBody EnableFactoryReq enableFactoryReq) throws Exception{
        //供应商启用
        factoryService.enableFactory(enableFactoryReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("供应商禁用")
    @PostMapping("disableFactory")
    public BaseResponse disableFactory(@Validated @RequestBody DisableFactoryReq disableFactoryReq) throws Exception{
        //供应商禁用
        factoryService.disableFactory(disableFactoryReq);
        //包装出参
        return BaseResponse.create();
    }

    @ResponseBody
    @ApiOperation(value = "导出模板")
    @GetMapping("downloadExcelModel")
    public void downloadExcelModel(HttpServletResponse response) throws Exception {
        ExcelInputFactory.downloadExcelModel("供应商模板", response, FactoryProperty.class);
    }

    @ApiOperation("excel批量导入")
    @PostMapping("factoryExcelImport")
    public BaseResponse factoryExcelImport(@RequestParam("file") MultipartFile file) throws Exception{
        List<FactoryProperty> factoryPropertyList = ExcelInputFactory.getExcelPojoList(file, FactoryProperty.class);
        //excel批量导入
        ExcelImportRes result = factoryService.factoryExcelImport(factoryPropertyList);
        //包装出参
        return BaseResponse.create(result);

    }



}








