package com.abi.qms.platform.controller.console;

import com.abi.qms.platform.dto.req.*;
import com.abi.qms.platform.dto.res.GetRoleInfoRes;
import com.abi.qms.platform.dto.res.ListResourceRes;
import com.abi.qms.platform.dto.res.ListRoleRes;
import com.abi.qms.platform.service.RoleManagerService;
import com.abi.task.common.api.base.BaseResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 角色管理
 * </p>
 *
 * @author Andy.Tan
 */
@Slf4j
@RestController
@Api(tags = "角色管理")
public class RoleManagerController {

    @Autowired
    private RoleManagerService roleManagerService;

    @ApiOperation("创建角色")
    @PostMapping("createRole")
    public BaseResponse createRole(@Validated @RequestBody CreateRoleReq createRoleReq) throws Exception{
        //创建角色
        roleManagerService.createRole(createRoleReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("修改角色")
    @PostMapping("updateRole")
    public BaseResponse updateRole(@Validated @RequestBody UpdateRoleReq updateRoleReq) throws Exception{
        //修改角色
        roleManagerService.updateRole(updateRoleReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("查询单个角色信息")
    @GetMapping("getRoleInfo")
    public BaseResponse<GetRoleInfoRes> getRoleInfo(@Validated GetRoleInfoReq getRoleInfoReq) throws Exception{
        //查询单个角色信息
        GetRoleInfoRes  result = roleManagerService.getRoleInfo(getRoleInfoReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("查询角色列表")
    @GetMapping("listRole")
    public BaseResponse<ListRoleRes> listRole(@Validated ListRoleReq listRoleReq) throws Exception{
        //查询角色列表
        ListRoleRes  result = roleManagerService.listRole(listRoleReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("查询当前用户能看到的资源")
    @GetMapping("listResource")
    public BaseResponse<ListResourceRes> listResource(@Validated ListResourceReq listResourceReq) throws Exception{
        //查询当前用户能看到的资源
        ListResourceRes  result = roleManagerService.listResource(listResourceReq);
        //包装出参
        return BaseResponse.create(result);
    }



}








