package com.abi.qms.platform.controller.console;

import com.abi.qms.platform.dto.req.CreateUserReq;
import com.abi.qms.platform.dto.req.GetUserInfoReq;
import com.abi.qms.platform.dto.req.ListUserReq;
import com.abi.qms.platform.dto.req.UpdateUserReq;
import com.abi.qms.platform.dto.res.GetUserInfoRes;
import com.abi.qms.platform.dto.res.ListUserRes;
import com.abi.qms.platform.service.UserManagerService;
import com.abi.task.common.api.base.BaseResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 用户管理
 * </p>
 *
 * @author Andy.Tan
 */
@Slf4j
@RestController
@Api(tags = "用户管理")
public class UserManagerController {

    @Autowired
    private UserManagerService userManagerService;

    @ApiOperation("创建用户")
    @PostMapping("createUser")
    public BaseResponse createUser(@Validated @RequestBody CreateUserReq createUserReq) throws Exception{
        //创建用户
        userManagerService.createUser(createUserReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("修改用户")
    @PostMapping("updateUser")
    public BaseResponse updateUser(@Validated @RequestBody UpdateUserReq updateUserReq) throws Exception{
        //修改用户
        userManagerService.updateUser(updateUserReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("查询单个用户信息")
    @GetMapping("getUserInfo")
    public BaseResponse<GetUserInfoRes> getUserInfo(@Validated GetUserInfoReq getUserInfoReq) throws Exception{
        //查询单个用户信息
        GetUserInfoRes  result = userManagerService.getUserInfo(getUserInfoReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("查询用户列表")
    @GetMapping("listUser")
    public BaseResponse<ListUserRes> listUser(@Validated ListUserReq listUserReq) throws Exception{
        //查询用户列表
        ListUserRes  result = userManagerService.listUser(listUserReq);
        //包装出参
        return BaseResponse.create(result);
    }



}








