package com.abi.qms.platform.infrastructure.aop;

import cn.hutool.json.JSONUtil;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;

/**
 * @Author: AndyTan
 */
@Component
@Aspect
@Slf4j
public class ServiceMethodParamLog {
	@Pointcut("execution(* com.abi..service..*(..))")
	public void aspect() {

	}

	@Around("aspect()")
	public Object before(ProceedingJoinPoint point) throws Throwable {
		//获取方法
		String className = point.getSignature().getDeclaringType().getSimpleName();
		String methodName = point.getSignature().getName();
		log.info(" ");
		log.info("--------->方法:"+className+"."+methodName+"()");
		log.info("--------->入参:"+getArgs(point));
		log.info(" ");
		Object proceed = point.proceed();
		log.info(" ");
		log.info("--------->出参: " + JSONUtil.toJsonStr(proceed));
		log.info("--------->结束:"+className+"."+methodName+"()");
		log.info(" ");
		return proceed;
	}

	private String getArgs(JoinPoint point) {
		try {
			String[] parameterNames = ((MethodSignature) point.getSignature()).getParameterNames();
			StringBuilder sb = new StringBuilder();
			for (int i = 0; i <parameterNames.length ; i++) {
				String arg = String.valueOf(point.getArgs()[i]);
				sb.append(parameterNames[i] + ":" + arg + ";");
			}
			return sb.toString();
		}catch (Exception e){
			log.info("拼接入参异常",e);
			return "";
		}
	}
}
